==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/RoutingEnrichmentsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dynamic
 * @property static
 */
public data class RoutingEnrichmentsArgs(
    public val `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null,
    public val static: Output<List<StaticRoutingEnrichmentArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs =
        com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder()
            .`dynamic`(
                `dynamic`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .static_(
                static?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RoutingEnrichmentsArgs].
 */
@PulumiTagMarker
public class RoutingEnrichmentsArgsBuilder internal constructor() {
    private var `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null

    private var static: Output<List<StaticRoutingEnrichmentArgs>>? = null

    /**
     * @param value
     */
    @JvmName("jltgxedsjfsdeuph")
    public suspend fun `dynamic`(`value`: Output<List<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = value
    }

    @JvmName("haenbpxaikyqqeaj")
    public suspend fun `dynamic`(vararg values: Output<DynamicRoutingEnrichmentArgs>) {
        this.`dynamic` = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("vwtqswwuldiqxtcl")
    public suspend fun `dynamic`(values: List<Output<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("fedcfvjcvuxutpxy")
    public suspend fun static(`value`: Output<List<StaticRoutingEnrichmentArgs>>) {
        this.static = value
    }

    @JvmName("rpfwpubkboearamh")
    public suspend fun static(vararg values: Output<StaticRoutingEnrichmentArgs>) {
        this.static = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("iqevtfangjjtugel")
    public suspend fun static(values: List<Output<StaticRoutingEnrichmentArgs>>) {
        this.static = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pmjfrjglukeoeelg")
    public suspend fun `dynamic`(`value`: List<DynamicRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tjasudtlsjwfxowx")
    public suspend
    fun `dynamic`(argument: List<suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ojtuhwautvudmgvj")
    public suspend fun `dynamic`(
        vararg
        argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("dhwgowshiwiqmxjk")
    public suspend fun `dynamic`(argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param values
     */
    @JvmName("oaioaeygyisrkpnq")
    public suspend fun `dynamic`(vararg values: DynamicRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param value
     */
    @JvmName("ivtpdcgijqhmjtrw")
    public suspend fun static(`value`: List<StaticRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tyiljwbrsavbrtpk")
    public suspend fun static(argument: List<suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pwjriybkffffvklo")
    public suspend fun static(
        vararg
        argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("knttrecmexoequbv")
    public suspend fun static(argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param values
     */
    @JvmName("qprcnnxsafnjommq")
    public suspend fun static(vararg values: StaticRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.static = mapped
    }

    internal fun build(): RoutingEnrichmentsArgs = RoutingEnrichmentsArgs(
        `dynamic` = `dynamic`,
        static = static,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/RoutingEnrichmentsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dynamic
 * @property static
 */
public data class RoutingEnrichmentsArgs(
    public val `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null,
    public val static: Output<List<StaticRoutingEnrichmentArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs =
        com.pulumi.azurenative.eventgrid.inputs.RoutingEnrichmentsArgs.builder()
            .`dynamic`(
                `dynamic`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .static_(
                static?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RoutingEnrichmentsArgs].
 */
@PulumiTagMarker
public class RoutingEnrichmentsArgsBuilder internal constructor() {
    private var `dynamic`: Output<List<DynamicRoutingEnrichmentArgs>>? = null

    private var static: Output<List<StaticRoutingEnrichmentArgs>>? = null

    /**
     * @param value
     */
    @JvmName("kfpipbahqokfumks")
    public suspend fun `dynamic`(`value`: Output<List<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = value
    }

    @JvmName("sxnovvvxdefhupfc")
    public suspend fun `dynamic`(vararg values: Output<DynamicRoutingEnrichmentArgs>) {
        this.`dynamic` = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("cjvkplkbuqntpefk")
    public suspend fun `dynamic`(values: List<Output<DynamicRoutingEnrichmentArgs>>) {
        this.`dynamic` = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("aedlsgqayxshuqsf")
    public suspend fun static(`value`: Output<List<StaticRoutingEnrichmentArgs>>) {
        this.static = value
    }

    @JvmName("iboauxcreirptdcq")
    public suspend fun static(vararg values: Output<StaticRoutingEnrichmentArgs>) {
        this.static = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("dpmsuftmtpydcxcj")
    public suspend fun static(values: List<Output<StaticRoutingEnrichmentArgs>>) {
        this.static = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pbfsdpyplibnhuap")
    public suspend fun `dynamic`(`value`: List<DynamicRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("einoikkfuemymacx")
    public suspend
    fun `dynamic`(argument: List<suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("okebjqmwbxphncyn")
    public suspend fun `dynamic`(
        vararg
        argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param argument
     */
    @JvmName("bwmoobdrqujegjtg")
    public suspend fun `dynamic`(argument: suspend DynamicRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            DynamicRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.`dynamic` = mapped
    }

    /**
     * @param values
     */
    @JvmName("fgovypwamkfacjih")
    public suspend fun `dynamic`(vararg values: DynamicRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`dynamic` = mapped
    }

    /**
     * @param value
     */
    @JvmName("wbnbhnwggwtfgwnf")
    public suspend fun static(`value`: List<StaticRoutingEnrichmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("umuxqxvxlejhswkw")
    public suspend fun static(argument: List<suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rkavnhocbrxxuynr")
    public suspend fun static(
        vararg
        argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param argument
     */
    @JvmName("bvlrmqjylngbbwar")
    public suspend fun static(argument: suspend StaticRoutingEnrichmentArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StaticRoutingEnrichmentArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.static = mapped
    }

    /**
     * @param values
     */
    @JvmName("agnoioujvfxetimm")
    public suspend fun static(vararg values: StaticRoutingEnrichmentArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.static = mapped
    }

    internal fun build(): RoutingEnrichmentsArgs = RoutingEnrichmentsArgs(
        `dynamic` = `dynamic`,
        static = static,
    )
}
